@@ -1,15 +1,9 @@
 <?php
 
-/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */
-
 /**
- * Logo handling - for printing
+ * Copyright © 2003-2024 The Galette Team
  *
- * PHP version 5
- *
- * Copyright © 2009-2014 The Galette Team
- *
- * This file is part of Galette (http://galette.tuxfamily.org).
+ * This file is part of Galette (https://galette.eu).
  *
  * Galette is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,18 +17,10 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with Galette. If not, see <http://www.gnu.org/licenses/>.
- *
- * @category  Core
- * @package   Galette
- *
- * @author    Johan Cwiklinski <johan@x-tnd.be>
- * @copyright 2009-2014 The Galette Team
- * @license   http://www.gnu.org/licenses/gpl-3.0.html GPL License 3.0 or (at your option) any later version
- * @version   SVN: $Id: print_logo.class.php 546 2009-03-05 06:09:00Z trashy $
- * @link      http://galette.tuxfamily.org
- * @since     Available since 0.7dev - 2009-09-20
  */
 
+declare(strict_types=1);
+
 namespace Galette\Core;
 
 /**
@@ -42,30 +28,23 @@ namespace Galette\Core;
  * from the default one.
  * If no print logo is found, we take the default Logo instead.
  *
- * @category  Core
- * @name      PrintLogo
- * @package   Galette
- * @author    Johan Cwiklinski <johan@x-tnd.be>
- * @copyright 2009-2014 The Galette Team
- * @license   http://www.gnu.org/licenses/gpl-3.0.html GPL License 3.0 or (at your option) any later version
- * @link      http://galette.tuxfamily.org
- * @since     Available since 0.7dev - 2009-09-20
+ * @author Johan Cwiklinski <johan@x-tnd.be>
 */
 class PrintLogo extends Logo
 {
-    protected $id = 'custom_print_logo';
+    protected string|int $id = 'custom_print_logo';
     //database wants a member id (integer), not a string.
     //Will be used to query the correct id
-    protected $db_id = 999999;
+    protected int $db_id = 999999;
 
     /**
-     * Gets the default picture to show, anyways
+     * Gets the default picture to show, anyway
      *
      * @see Logo::getDefaultPicture()
      *
      * @return void
      */
-    protected function getDefaultPicture()
+    protected function getDefaultPicture(): void
     {
         //if we are here, we want to serve default logo
         $pic = new Logo();
@@ -75,5 +54,4 @@ class PrintLogo extends Logo
         //anyways, we have no custom print logo
         $this->custom = false;
     }
-
 }
