@@ -1,15 +1,9 @@
 <?php
 
-/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */
-
 /**
- * Import model
+ * Copyright © 2003-2024 The Galette Team
  *
- * PHP version 5
- *
- * Copyright © 2013-2014 The Galette Team
- *
- * This file is part of Galette (http://galette.tuxfamily.org).
+ * This file is part of Galette (https://galette.eu).
  *
  * Galette is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,50 +17,40 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with Galette. If not, see <http://www.gnu.org/licenses/>.
- *
- * @category  Entity
- * @package   Galette
- *
- * @author    Johan Cwiklinski <johan@x-tnd.be>
- * @copyright 2013-2014 The Galette Team
- * @license   http://www.gnu.org/licenses/gpl-3.0.html GPL License 3.0 or (at your option) any later version
- * @version   SVN: $Id$
- * @link      http://galette.tuxfamily.org
- * @since     Available since 0.7.6dev - 2013-09-26
  */
 
+declare(strict_types=1);
+
 namespace Galette\Entity;
 
-use Analog\Analog as Analog;
-use Zend\Db\Adapter\Adapter;
+use ArrayObject;
+use Galette\Core\Db;
+use Galette\Core\Galette;
+use Throwable;
+use Analog\Analog;
+use Laminas\Db\Adapter\Adapter;
 
 /**
  * Import model entity
  *
- * @category  Entity
- * @name      ImportModel
- * @package   Galette
- * @author    Johan Cwiklinski <johan@x-tnd.be>
- * @copyright 2013-2014 The Galette Team
- * @license   http://www.gnu.org/licenses/gpl-3.0.html GPL License 3.0 or (at your option) any later version
- * @link      http://galette.tuxfamily.org
- * @since     Available since 0.7.6dev - 2013-09-26
+ * @author Johan Cwiklinski <johan@x-tnd.be>
  */
 class ImportModel
 {
-    const TABLE = 'import_model';
-    const PK = 'model_id';
+    public const TABLE = 'import_model';
+    public const PK = 'model_id';
 
-    private $_id;
-    private $_fields;
-    private $_creation_date;
+    private ?int $id;
+    /** @var array<string>|null */
+    private ?array $fields;
+    private ?string $creation_date;
 
     /**
      * Loads model
      *
      * @return bool true if query succeed, false otherwise
      */
-    public function load()
+    public function load(): bool
     {
         global $zdb;
 
@@ -77,34 +61,38 @@ class ImportModel
             $results = $zdb->execute($select);
             $result = $results->current();
 
-            if ( $result ) {
-                $this->_loadFromRS($result);
+            if ($result) {
+                $this->loadFromRS($result);
                 return true;
             } else {
                 return false;
             }
-        } catch (\Exception $e) {
+        } catch (Throwable $e) {
             Analog::log(
                 'Cannot load import model | ' . $e->getMessage() .
-                "\n" .  $e->__toString(),
+                "\n" . $e->__toString(),
                 Analog::ERROR
             );
-            return false;
+            throw $e;
         }
     }
 
     /**
      * Populate object from a resultset row
      *
-     * @param ResultSet $r the resultset row
+     * @param ArrayObject<string, int|string> $r the resultset row
      *
      * @return void
      */
-    private function _loadFromRS($r)
+    private function loadFromRS(ArrayObject $r): void
     {
-        $this->_id = $r->model_id;
-        $this->_fields = unserialize($r->model_fields);
-        $this->_creation_date = $r->model_creation_date;
+        $this->id = (int)$r->model_id;
+        if (Galette::isSerialized($r->model_fields)) {
+            $this->fields = unserialize($r->model_fields);
+        } else {
+            $this->fields = Galette::jsonDecode($r->model_fields);
+        }
+        $this->creation_date = $r->model_creation_date;
     }
 
     /**
@@ -114,27 +102,24 @@ class ImportModel
      *
      * @return boolean
      */
-    public function remove($zdb)
+    public function remove(Db $zdb): bool
     {
         try {
-            $result = $zdb->db->query(
+            $zdb->db->query(
                 'TRUNCATE TABLE ' . PREFIX_DB . self::TABLE,
                 Adapter::QUERY_MODE_EXECUTE
             );
 
-            if ( $result ) {
-                $this->_id = null;
-                $this->_fields = null;
-                $this->_creation_date = null;
-            }
-
-            return $result;
-        } catch (\Exception $e) {
+            $this->id = null;
+            $this->fields = null;
+            $this->creation_date = null;
+            return true;
+        } catch (Throwable $e) {
             Analog::log(
                 'Unable to remove import model ' . $e->getMessage(),
                 Analog::ERROR
             );
-            return false;
+            throw $e;
         }
     }
 
@@ -145,57 +130,56 @@ class ImportModel
      *
      * @return boolean
      */
-    public function store($zdb)
+    public function store(Db $zdb): bool
     {
         try {
             $values = array(
-                self::PK        => $this->_id,
-                'model_fields'  => serialize($this->_fields)
+                'model_fields'  => Galette::jsonEncode($this->fields)
             );
 
-            if ( !isset($this->_id) || $this->_id == '') {
+            if (!isset($this->id) || $this->id == '') {
                 //we're inserting a new model
-                unset($values[self::PK]);
-                $this->_creation_date = date("Y-m-d H:i:s");
-                $values['model_creation_date'] = $this->_creation_date;
+                $this->creation_date = date("Y-m-d H:i:s");
+                $values['model_creation_date'] = $this->creation_date;
 
                 $insert = $zdb->insert(self::TABLE);
                 $insert->values($values);
                 $results = $zdb->execute($insert);
 
-                if ( $results->count() > 0) {
+                if ($results->count() > 0) {
                     return true;
                 } else {
                     throw new \Exception(
-                        'An error occured inserting new import model!'
+                        'An error occurred inserting new import model!'
                     );
                 }
             } else {
                 //we're editing an existing model
+                $values[self::PK] = $this->id;
                 $update = $zdb->update(self::TABLE);
                 $update->set($values);
-                $update->where(self::PK . '=' . $this->_id);
+                $update->where([self::PK => $this->id]);
                 $zdb->execute($update);
                 return true;
             }
-        } catch ( \Exception $e ) {
+        } catch (Throwable $e) {
             Analog::log(
                 'Something went wrong storing import model :\'( | ' .
                 $e->getMessage() . "\n" . $e->getTraceAsString(),
                 Analog::ERROR
             );
-            return false;
+            throw $e;
         }
     }
 
     /**
      * Get fields
      *
-     * @return array
+     * @return ?array<string>
      */
-    public function getFields()
+    public function getFields(): ?array
     {
-        return $this->_fields;
+        return $this->fields ?? null;
     }
 
     /**
@@ -205,25 +189,26 @@ class ImportModel
      *
      * @return string
      */
-    public function getCreationDate($formatted = true)
+    public function getCreationDate(bool $formatted = true): string
     {
-        if ( $formatted === true ) {
-            $date = new \DateTime($this->_creation_date);
-            return $date->format(_T("Y-m-d"));
+        if ($formatted === true) {
+            $date = new \DateTime($this->creation_date);
+            return $date->format(__("Y-m-d"));
         } else {
-            return $this->_creation_date;
+            return $this->creation_date;
         }
     }
 
     /**
      * Set fields
      *
-     * @param array $fields Fields list
+     * @param array<string> $fields Fields list
      *
-     * @return void
+     * @return self
      */
-    public function setFields($fields)
+    public function setFields(array $fields): self
     {
-        $this->_fields = $fields;
+        $this->fields = $fields;
+        return $this;
     }
 }
