@@ -1,15 +1,9 @@
 <?php
 
-/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */
-
 /**
- * Galette's charts
+ * Copyright © 2003-2024 The Galette Team
  *
- * PHP version 5
- *
- * Copyright © 2013-2014 The Galette Team
- *
- * This file is part of Galette (http://galette.tuxfamily.org).
+ * This file is part of Galette (https://galette.eu).
  *
  * Galette is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,23 +17,16 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with Galette. If not, see <http://www.gnu.org/licenses/>.
- *
- * @category  IO
- * @package   Galette
- *
- * @author    Johan Cwiklinski <johan@x-tnd.be>
- * @copyright 2013-2014 The Galette Team
- * @license   http://www.gnu.org/licenses/gpl-3.0.html GPL License 3.0 or (at your option) any later version
- * @version   SVN: $Id$
- * @link      http://galette.tuxfamily.org
- * @since     Available since 0.7.4dev - 2013-02-02
  */
 
+declare(strict_types=1);
+
 namespace Galette\IO;
 
 use Analog\Analog;
-use Zend\Db\Sql\Expression;
-use Zend\Db\Sql\Predicate\PredicateSet;
+use Galette\Core\Db;
+use Laminas\Db\Sql\Expression;
+use Laminas\Db\Sql\Predicate\PredicateSet;
 use Galette\Entity\Status;
 use Galette\Entity\Adherent;
 use Galette\Entity\Contribution;
@@ -49,44 +36,39 @@ use Galette\Repository\Members;
 /**
  * Charts class for galette
  *
- * @category  Charts
- * @name      Charts
- * @package   Galette
- * @author    Johan Cwiklinski <johan@x-tnd.be>
- * @copyright 2013-2014 The Galette Team
- * @license   http://www.gnu.org/licenses/gpl-3.0.html GPL License 3.0 or (at your option) any later version
- * @link      http://galette.tuxfamily.org
- * @since     Available since 0.7.4dev - 2013-02-02
+ * @author Johan Cwiklinski <johan@x-tnd.be>
  */
 class Charts
 {
-    const DEFAULT_CHART = 'MembersStatusPie';
-    const MEMBERS_STATUS_PIE = 'MembersStatusPie';
-    const MEMBERS_STATEDUE_PIE = 'MembersStateDuePie';
-    const CONTRIBS_TYPES_PIE = 'ContribsTypesPie';
-    const COMPANIES_OR_NOT = 'CompaniesOrNot';
-    const CONTRIBS_ALLTIME = 'ContribsAllTime';
+    public const DEFAULT_CHART = 'MembersStatusPie';
+    public const MEMBERS_STATUS_PIE = 'MembersStatusPie';
+    public const MEMBERS_STATEDUE_PIE = 'MembersStateDuePie';
+    public const CONTRIBS_TYPES_PIE = 'ContribsTypesPie';
+    public const COMPANIES_OR_NOT = 'CompaniesOrNot';
+    public const CONTRIBS_ALLTIME = 'ContribsAllTime';
 
-    private $_types;
-    private $_charts;
+    /** @var array<string>|null  */
+    private ?array $types;
+    /** @var array<string> */
+    private array $charts;
 
     /**
      * Default constructor
      *
-     * @param array $types Charts types to cache
+     * @param ?array<string> $types Charts types to cache
      */
-    public function __construct($types = null)
+    public function __construct(array $types = null)
     {
-        if ( $types !== null ) {
-            if ( !is_array($types) ) {
+        if ($types !== null) {
+            if (!is_array($types)) {
                 $types = array($types);
             }
-            $this->_types = $types;
+            $this->types = $types;
         } else {
-            $this->_types = array(self::DEFAULT_CHART);
+            $this->types = array(self::DEFAULT_CHART);
         }
 
-        $this->_load();
+        $this->load();
     }
 
     /**
@@ -94,10 +76,10 @@ class Charts
      *
      * @return void
      */
-    private function _load()
+    private function load(): void
     {
-        foreach ( $this->_types as $t ) {
-            $classname = "_getChart" . $t;
+        foreach ($this->types as $t) {
+            $classname = "getChart" . $t;
             $this->$classname();
         }
     }
@@ -105,11 +87,11 @@ class Charts
     /**
      * Retrieve loaded charts
      *
-     * @return array
+     * @return array<string,string>
      */
-    public function getCharts()
+    public function getCharts(): array
     {
-        return $this->_charts;
+        return $this->charts;
     }
 
     /**
@@ -117,7 +99,7 @@ class Charts
      *
      * @return void
      */
-    private function _getChartMembersStatusPie()
+    private function getChartMembersStatusPie(): void
     {
         global $zdb;
 
@@ -133,25 +115,28 @@ class Charts
             'a.' . Status::PK . '=b.' . Status::PK,
             array()
         )
+            ->where(array('b.activite_adh' => new Expression('true')))
             ->order('a.priorite_statut')
             ->group('a.' . Status::PK);
 
         $results = $zdb->execute($select);
 
-        $chart = array();
-        $staff = array(_T("Staff members"), 0);
-        foreach ( $results as $r ) {
-            if ( $r->priority >= Members::NON_STAFF_MEMBERS ) {
-                $chart[] = array(
-                    _T($r->status),
-                    (int)$r->cnt
-                );
+        $chart_labels = array();
+        $chart_data = array();
+        $staff_label = _T("Staff members");
+        $staff_data = 0;
+        foreach ($results as $r) {
+            if ($r->priority >= Members::NON_STAFF_MEMBERS) {
+                $chart_labels[] = _T($r->status);
+                $chart_data[] = (int)$r->cnt;
             } else {
-                $staff[1] += $r->cnt;
+                $staff_data += $r->cnt;
             }
         }
-        $chart[] = $staff;
-        $this->_charts[self::MEMBERS_STATUS_PIE] = json_encode($chart);
+        $chart_labels[] = $staff_label;
+        $chart_data[] = $staff_data;
+        $this->charts[self::MEMBERS_STATUS_PIE . 'Labels'] = json_encode($chart_labels);
+        $this->charts[self::MEMBERS_STATUS_PIE . 'Data'] = json_encode($chart_data);
     }
 
     /**
@@ -159,40 +144,42 @@ class Charts
      *
      * @return void
      */
-    private function _getChartMembersStateDuePie()
+    private function getChartMembersStateDuePie(): void
     {
         global $zdb;
 
-        $chart = array();
+        $chart_labels = array();
+        $chart_data = array();
         $select = $zdb->select(Adherent::TABLE, 'a');
         $select->columns(
             array(
                 'cnt' => new Expression('COUNT(a.' . Adherent::PK . ')')
             )
-        )->where(array('bool_exempt_adh' => new Expression('true')));
+        )
+            ->where(array('activite_adh' => new Expression('true')))
+            ->where(array('bool_exempt_adh' => new Expression('true')));
 
         $results = $zdb->execute($select);
         $result = $results->current();
 
-        $chart[] = array(
-            _T("Due free"),
-            (int)$result->cnt
-        );
+        $chart_labels[] = _T("Due free");
+        $chart_data[] = (int)$result->cnt;
 
         $select = $zdb->select(Adherent::TABLE, 'a');
         $select->columns(
             array(
                 'cnt' => new Expression('COUNT(a.' . Adherent::PK . ')')
             )
-        )->where('date_echeance IS NULL');
+        )
+            ->where(array('activite_adh' => new Expression('true')))
+            ->where(array('bool_exempt_adh' => new Expression('false')))
+            ->where('date_echeance IS NULL');
 
         $results = $zdb->execute($select);
         $result = $results->current();
 
-        $chart[] = array(
-            _T("Never contribute"),
-            (int)$result->cnt
-        );
+        $chart_labels[] = _T("Never contribute");
+        $chart_data[] = (int)$result->cnt;
 
         $soon_date = new \DateTime();
         $soon_date->modify('+30 day');
@@ -205,48 +192,51 @@ class Charts
                 'cnt' => new Expression('COUNT(a.' . Adherent::PK . ')')
             )
         )
+            ->where(array('activite_adh' => new Expression('true')))
+            ->where(array('bool_exempt_adh' => new Expression('false')))
             ->where->lessThanOrEqualTo('date_echeance', $soon_date->format('Y-m-d'))
             ->where->greaterThanOrEqualTo('date_echeance', $now->format('Y-m-d'));
 
         $results = $zdb->execute($select);
         $result = $results->current();
 
-        $chart[] = array(
-            _T("Impending due dates"),
-            (int)$result->cnt
-        );
+        $chart_labels[] = _T("Impending due dates");
+        $chart_data[] = (int)$result->cnt;
 
         $select = $zdb->select(Adherent::TABLE, 'a');
         $select->columns(
             array(
                 'cnt' => new Expression('COUNT(a.' . Adherent::PK . ')')
             )
-        )->where->greaterThan('date_echeance', $now->format('Y-m-d'));
+        )
+            ->where(array('activite_adh' => new Expression('true')))
+            ->where(array('bool_exempt_adh' => new Expression('false')))
+            ->where->greaterThan('date_echeance', $now->format('Y-m-d'));
 
         $results = $zdb->execute($select);
         $result = $results->current();
 
-        $chart[] = array(
-            _T("Up to date"),
-            (int)$result->cnt
-        );
+        $chart_labels[] = _T("Up to date");
+        $chart_data[] = (int)$result->cnt;
 
         $select = $zdb->select(Adherent::TABLE, 'a');
         $select->columns(
             array(
                 'cnt' => new Expression('COUNT(a.' . Adherent::PK . ')')
             )
-        )->where->lessThan('date_echeance', $now->format('Y-m-d'));
+        )
+            ->where(array('activite_adh' => new Expression('true')))
+            ->where(array('bool_exempt_adh' => new Expression('false')))
+            ->where->lessThan('date_echeance', $now->format('Y-m-d'));
 
         $results = $zdb->execute($select);
         $result = $results->current();
 
-        $chart[] = array(
-            _T("Late"),
-            (int)$result->cnt
-        );
+        $chart_labels[] = _T("Late");
+        $chart_data[] = (int)$result->cnt;
 
-        $this->_charts[self::MEMBERS_STATEDUE_PIE] = json_encode($chart);
+        $this->charts[self::MEMBERS_STATEDUE_PIE . 'Labels'] = json_encode($chart_labels);
+        $this->charts[self::MEMBERS_STATEDUE_PIE . 'Data'] = json_encode($chart_data);
     }
 
     /**
@@ -254,7 +244,7 @@ class Charts
      *
      * @return void
      */
-    private function _getChartCompaniesOrNot()
+    private function getChartCompaniesOrNot(): void
     {
         global $zdb;
 
@@ -287,25 +277,25 @@ class Charts
         $results = $zdb->execute($select1);
 
         $result = $results->current();
+        $results->next();
         $next = $results->current();
 
         $individuals = $result->cnt;
         $companies = 0;
-        if ( $next ) {
+        if ($next) {
             $companies = $next->cnt;
         }
 
-        $chart = array(
-            array(
-                _T("Individuals"),
-                (int)$individuals
-            ),
-            array(
-                _T("Companies"),
-                (int)$companies
-            )
-        );
-        $this->_charts[self::COMPANIES_OR_NOT] = json_encode($chart);
+        $chart_labels = [
+            _T("Individuals"),
+            _T("Companies")
+        ];
+        $chart_data = [
+            (int)$individuals,
+            (int)$companies
+        ];
+        $this->charts[self::COMPANIES_OR_NOT . 'Labels'] = json_encode($chart_labels);
+        $this->charts[self::COMPANIES_OR_NOT . 'Data'] = json_encode($chart_data);
     }
 
     /**
@@ -313,7 +303,7 @@ class Charts
      *
      * @return void
      */
-    private function _getChartContribsTypesPie()
+    private function getChartContribsTypesPie(): void
     {
         global $zdb;
 
@@ -334,14 +324,14 @@ class Charts
 
         $results = $zdb->execute($select);
 
-        $chart = array();
-        foreach ( $results as $r ) {
-            $chart[] = array(
-                _T($r->label),
-                (int)$r->cnt
-            );
+        $chart_labels = array();
+        $chart_data = array();
+        foreach ($results as $r) {
+            $chart_labels[] = _T($r->label);
+            $chart_data[] = (int)$r->cnt;
         }
-        $this->_charts[self::CONTRIBS_TYPES_PIE] = json_encode($chart);
+        $this->charts[self::CONTRIBS_TYPES_PIE . 'Labels'] = json_encode($chart_labels);
+        $this->charts[self::CONTRIBS_TYPES_PIE . 'Data'] = json_encode($chart_data);
     }
 
     /**
@@ -349,8 +339,9 @@ class Charts
      *
      * @return void
      */
-    private function _getChartContribsAllTime()
+    private function getChartContribsAllTime(): void
     {
+        /** @var Db $zdb */
         global $zdb;
 
         $select = $zdb->select(Contribution::TABLE);
@@ -361,29 +352,26 @@ class Charts
         );
         $groupby = null;
 
-        if ( TYPE_DB === 'pgsql' ) {
+        if ($zdb->isPostgres()) {
             $cols['date'] = new Expression('date_trunc(\'month\', date_enreg)');
             $groupby = new Expression('date_trunc(\'month\', date_enreg)');
-        } else if ( TYPE_DB === 'mysql' ) {
+        } else {
             $cols['date'] = new Expression('date_format(date_enreg, \'%Y-%m\')');
-            $groupby = new Expression('EXTRACT(YEAR_MONTH FROM date_enreg)');
-        } else if ( TYPE_DB === 'sqlite') {
-            $cols['date'] = new Expression('STRFTIME("%Y-%m-%d", date_enreg)');
-            $groupby = 'date';
+            $groupby = new Expression('date_format(date_enreg, \'%Y-%m\')');
         }
 
         $select->columns($cols)->group($groupby)->order('date ASC');
 
         $results = $zdb->execute($select);
 
-        $chart = array();
-        foreach ( $results as $r ) {
+        $chart_labels = [];
+        $chart_data = [];
+        foreach ($results as $r) {
             $d = new \DateTime($r->date);
-            $chart[] = array(
-                $d->format('Y-m'),
-                (float)$r->amount
-            );
+            $chart_labels[] = $d->format('Y-m');
+            $chart_data[] = (float)$r->amount;
         }
-        $this->_charts[self::CONTRIBS_ALLTIME] = json_encode($chart);
+        $this->charts[self::CONTRIBS_ALLTIME . 'Labels'] = json_encode($chart_labels);
+        $this->charts[self::CONTRIBS_ALLTIME . 'Data'] = json_encode($chart_data);
     }
 }
