@@ -1,15 +1,9 @@
 <?php
 
-/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */
-
 /**
- * PDF models
+ * Copyright © 2003-2024 The Galette Team
  *
- * PHP version 5
- *
- * Copyright © 2013-2014 The Galette Team
- *
- * This file is part of Galette (http://galette.tuxfamily.org).
+ * This file is part of Galette (https://galette.eu).
  *
  * Galette is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,22 +17,16 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with Galette. If not, see <http://www.gnu.org/licenses/>.
- *
- * @category  Repository
- * @package   Galette
- *
- * @author    Johan Cwiklinski <johan@x-tnd.be>
- * @copyright 2011-2014 The Galette Team
- * @license   http://www.gnu.org/licenses/gpl-3.0.html GPL License 3.0 or (at your option) any later version
- * @version   SVN: $Id$
- * @link      http://galette.tuxfamily.org
- * @since     Available since 0.7.5dev - 2013-02-25
  */
 
+declare(strict_types=1);
+
 namespace Galette\Repository;
 
+use Laminas\Db\ResultSet\ResultSet;
+use Throwable;
 use Analog\Analog;
-use Zend\Db\Sql\Expression;
+use Laminas\Db\Sql\Expression;
 use Galette\Entity\PdfModel;
 use Galette\Entity\PdfMain;
 use Galette\Entity\PdfInvoice;
@@ -47,23 +35,16 @@ use Galette\Entity\PdfReceipt;
 /**
  * PDF models
  *
- * @category  Repository
- * @name      PdfModels
- * @package   Galette
- * @author    Johan Cwiklinski <johan@x-tnd.be>
- * @copyright 2013-2014 The Galette Team
- * @license   http://www.gnu.org/licenses/gpl-3.0.html GPL License 3.0 or (at your option) any later version
- * @link      http://galette.tuxfamily.org
- * @since     Available since 0.7.5dev - 2013-02-25
+ * @author Johan Cwiklinski <johan@x-tnd.be>
  */
 class PdfModels extends Repository
 {
     /**
      * Get models list
      *
-     * @return PdfModel[]
+     * @return array<int, PdfModel>|ResultSet
      */
-    public function getList()
+    public function getList(): array|ResultSet
     {
         try {
             $select = $this->zdb->select(PdfModel::TABLE, 'a');
@@ -71,35 +52,35 @@ class PdfModels extends Repository
 
             $models = array();
             $results = $this->zdb->execute($select);
-            foreach ( $results as $row ) {
-                $class = PdfModel::getTypeClass($row->model_type);
+            foreach ($results as $row) {
+                $class = PdfModel::getTypeClass((int)$row->model_type);
                 $models[] = new $class($this->zdb, $this->preferences, $row);
             }
             return $models;
-        } catch (\Exception $e) {
+        } catch (Throwable $e) {
             Analog::log(
                 'Cannot list pdf models | ' . $e->getMessage(),
                 Analog::WARNING
             );
+            throw $e;
         }
     }
 
     /**
      * Add default models in database
      *
-     * @param array   $defaults    Fields definition defaults
-     * @param boolean $check_first Check first if it seem initialized
+     * @param boolean $check_first Check first if it seems initialized
      *
      * @return boolean
      */
-    public function installInit($defaults, $check_first = true)
+    public function installInit(bool $check_first = true): bool
     {
         try {
             $ent = $this->entity;
             //first of all, let's check if data seem to have already
             //been initialized
             $proceed = false;
-            if ( $check_first === true ) {
+            if ($check_first === true) {
                 $select = $this->zdb->select(PdfModel::TABLE);
                 $select->columns(
                     array(
@@ -110,12 +91,12 @@ class PdfModels extends Repository
                 $results = $this->zdb->execute($select);
                 $result = $results->current();
                 $count = $result->counter;
-                if ( $count == 0 ) {
+                if ($count == 0) {
                     //if we got no values in texts table, let's proceed
                     $proceed = true;
                 } else {
-                    if ( $count < count($defaults) ) {
-                        return $this->_checkUpdate($defaults);
+                    if ($count < count($this->defaults)) {
+                        return $this->checkUpdate();
                     }
                     return false;
                 }
@@ -123,56 +104,67 @@ class PdfModels extends Repository
                 $proceed = true;
             }
 
-            if ( $proceed === true ) {
+            if ($proceed === true) {
                 $this->zdb->connection->beginTransaction();
 
                 //first, we drop all values
+                $update = $this->zdb->update($ent::TABLE);
+                $update->set(['model_parent' => null]);
+                $this->zdb->execute($update);
+
                 $delete = $this->zdb->delete($ent::TABLE);
                 $this->zdb->execute($delete);
-                $this->_insert($ent::TABLE, $defaults);
+
+                $this->zdb->handleSequence(
+                    $ent::TABLE,
+                    count($this->defaults)
+                );
+
+                $this->insert($ent::TABLE, $this->defaults);
 
                 $this->zdb->connection->commit();
                 return true;
             }
-        } catch (\Exception $e) {
-            $this->zdb->connection->rollBack();
-            return $e;
+        } catch (Throwable $e) {
+            if ($this->zdb->connection->inTransaction()) {
+                $this->zdb->connection->rollBack();
+            }
+            throw $e;
         }
     }
 
     /**
      * Checks for missing texts in the database
      *
-     * @param array $defaults Fields definition defaults
-     *
      * @return boolean
      */
-    private function _checkUpdate($defaults)
+    protected function checkUpdate(): bool
     {
         try {
             $ent = $this->entity;
             $select = $this->zdb->select($ent::TABLE);
             $list = $this->zdb->execute($select);
+            $list->buffer();
 
             $missing = array();
-            foreach ( $defaults as $default ) {
+            foreach ($this->defaults as $key => $default) {
                 $exists = false;
-                foreach ( $list as $model ) {
-                    if ( $model->model_id == $default['model_id'] ) {
+                foreach ($list as $model) {
+                    if ($model->model_id == $default['model_id']) {
                         $exists = true;
                         break;
                     }
                 }
 
-                if ( $exists === false ) {
-                    //model does not exists in database, insert it.
-                    $missing[] = $default;
+                if ($exists === false) {
+                    //model does not exist in database, insert it.
+                    $missing[$key] = $default;
                 }
             }
 
-            if ( count($missing) >0 ) {
+            if (count($missing) > 0) {
                 $this->zdb->connection->beginTransaction();
-                $this->_insert($ent::TABLE, $missing);
+                $this->insert($ent::TABLE, $missing);
                 Analog::log(
                     'Missing texts were successfully stored into database.',
                     Analog::INFO
@@ -180,21 +172,24 @@ class PdfModels extends Repository
                 $this->zdb->connection->commit();
                 return true;
             }
-        } catch (\Exception $e) {
-            $this->zdb->connection->rollBack();
+        } catch (Throwable $e) {
+            if ($this->zdb->connection->inTransaction()) {
+                $this->zdb->connection->rollBack();
+            }
             throw $e;
         }
+        return false;
     }
 
     /**
      * Insert values in database
      *
-     * @param string $table  Table name
-     * @param array  $values Values to insert
+     * @param string              $table  Table name
+     * @param array<string,mixed> $values Values to insert
      *
      * @return void
      */
-    private function _insert($table, $values)
+    private function insert(string $table, array $values): void
     {
         $insert = $this->zdb->insert($table);
         $insert->values(
@@ -212,9 +207,23 @@ class PdfModels extends Repository
         );
         $stmt = $this->zdb->sql->prepareStatementForSqlObject($insert);
 
-        foreach ( $values as $value ) {
+        foreach ($values as $value) {
             $stmt->execute($value);
         }
     }
-}
 
+    /**
+     * Load and get default PDF models
+     *
+     * @return array<string,mixed>
+     */
+    protected function loadDefaults(): array
+    {
+        if (!count($this->defaults)) {
+            include GALETTE_ROOT . 'includes/fields_defs/pdfmodels_fields.php';
+            //@phpstan-ignore-next-line
+            $this->defaults = $pdfmodels_fields;
+        }
+        return parent::loadDefaults();
+    }
+}
