@@ -1,15 +1,9 @@
 <?php
 
-/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */
-
 /**
- * Titles repository management
+ * Copyright © 2003-2024 The Galette Team
  *
- * PHP version 5
- *
- * Copyright © 2009-2014 The Galette Team
- *
- * This file is part of Galette (http://galette.tuxfamily.org).
+ * This file is part of Galette (https://galette.eu).
  *
  * Galette is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,47 +17,34 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with Galette. If not, see <http://www.gnu.org/licenses/>.
- *
- * @category  Entity
- * @package   Galette
- *
- * @author    Johan Cwiklinski <johan@x-tnd.be>
- * @copyright 2009-2014 The Galette Team
- * @license   http://www.gnu.org/licenses/gpl-3.0.html GPL License 3.0 or (at your option) any later version
- * @version   SVN: $Id$
- * @link      http://galette.tuxfamily.org
- * @since     Available since 0.7dev - 2009-03-04
  */
 
+declare(strict_types=1);
+
 namespace Galette\Repository;
 
-use Galette\Entity\Title as Title;
-use Analog\Analog as Analog;
-use Zend\Db\Sql\Expression;
+use Galette\Core\Db;
+use Throwable;
+use Galette\Entity\Title;
+use Analog\Analog;
 
 /**
  * Titles repository management
  *
- * @category  Entity
- * @name      Titles
- * @package   Galette
- * @author    Johan Cwiklinski <johan@x-tnd.be>
- * @copyright 2009-2014 The Galette Team
- * @license   http://www.gnu.org/licenses/gpl-3.0.html GPL License 3.0 or (at your option) any later version
- * @link      http://galette.tuxfamily.org
- * @since     Available since 0.7dev - 2009-03-04
+ * @author Johan Cwiklinski <johan@x-tnd.be>
  */
 
 class Titles
 {
-    const TABLE = 'titles';
-    const PK = 'id_title';
+    public const TABLE = 'titles';
+    public const PK = 'id_title';
 
-    const MR = 1;
-    const MRS = 2;
-    const MISS = 3;
+    public const MR = 1;
+    public const MRS = 2;
+    public const MISS = 3;
 
-    private static $_defaults = array(
+    /** @var array<array<string,mixed>> */
+    private static array $defaults = array(
         array(
             'id_title'      => 1,
             'short_label'   => 'Mr.',
@@ -76,22 +57,32 @@ class Titles
         )
     );
 
+    private Db $zdb;
+
+    /**
+     * Default constructor
+     *
+     * @param Db $zdb Database instance
+     */
+    public function __construct(Db $zdb)
+    {
+        $this->zdb = $zdb;
+    }
+
     /**
      * Get the list of all titles
      *
-     * @param Db $zdb Database instance
-     *
-     * @return array
+     * @return Title[]
      */
-    public static function getList($zdb)
+    public function getList(): array
     {
-        $select = $zdb->select(self::TABLE);
+        $select = $this->zdb->select(self::TABLE);
         $select->order(self::PK);
 
-        $results = $zdb->execute($select);
+        $results = $this->zdb->execute($select);
 
         $pols = array();
-        foreach ( $results as $r ) {
+        foreach ($results as $r) {
             $pk = self::PK;
             $pols[$r->$pk] = new Title($r);
         }
@@ -102,18 +93,17 @@ class Titles
     /**
      * Set default titles at install time
      *
-     * @param Db $zdb Database instance
-     *
-     * @return boolean|Exception
+     * @return boolean
+     * @throws Throwable
      */
-    public function installInit($zdb)
+    public function installInit(): bool
     {
         try {
             //first, we drop all values
-            $delete = $zdb->delete(self::TABLE);
-            $zdb->execute($delete);
+            $delete = $this->zdb->delete(self::TABLE);
+            $this->zdb->execute($delete);
 
-            $insert = $zdb->insert(self::TABLE);
+            $insert = $this->zdb->insert(self::TABLE);
             $insert->values(
                 array(
                     'id_title'      => ':id',
@@ -121,21 +111,24 @@ class Titles
                     'long_label'    => ':long'
                 )
             );
-            $stmt = $zdb->sql->prepareStatementForSqlObject($insert);
+            $stmt = $this->zdb->sql->prepareStatementForSqlObject($insert);
 
-            foreach ( self::$_defaults as $d ) {
+            $this->zdb->handleSequence(
+                self::TABLE,
+                count(self::$defaults)
+            );
+
+            foreach (self::$defaults as $d) {
                 $short = _T($d['short_label']);
                 $long = null;
-                if ( $d['long_label'] !== null ) {
+                if ($d['long_label'] !== null) {
                     $long = _T($d['long_label']);
-                } else {
-                    $long = 'NULL';
                 }
                 $stmt->execute(
                     array(
-                        'id_title'      => $d['id_title'],
-                        'short_label'   => $short,
-                        'long_label'    => $long
+                        'id'    => $d['id_title'],
+                        'short' => $short,
+                        'long'  => $long
                     )
                 );
             }
@@ -145,33 +138,12 @@ class Titles
                 Analog::INFO
             );
             return true;
-        } catch (\Exception $e) {
+        } catch (Throwable $e) {
             Analog::log(
                 'Unable to initialize default titles. ' . $e->getMessage(),
                 Analog::WARNING
             );
-            return $e;
+            throw $e;
         }
     }
-
-    /**
-     * Get the title
-     *
-     * @param integer $title The title id to retrieve
-     *
-     * @return translated title short version
-     */
-    public static function getTitle($title)
-    {
-        global $zdb;
-
-        $select = $zdb->select(self::TABLE);
-        $select->limit(1)
-            ->where(array(self::PK => $title));
-
-        $results = $zdb->execute($select);
-        $result = $results->current();
-        $res = $result->short_label;
-        return _T($res);
-    }
 }
